@@ -3,13 +3,17 @@
  *
  * See Copyright for the status of this software.
  *
- * Daniel.Veillard@w3.org
+ * daniel@veillard.com
  */
  
 #ifndef __NANO_HTTP_H__
 #define __NANO_HTTP_H__
 
+#if defined(WIN32) && defined(_MSC_VER)
+#include <libxml/xmlwin32version.h>
+#else
 #include <libxml/xmlversion.h>
+#endif
 #ifdef LIBXML_HTTP_ENABLED
 
 #ifdef __cplusplus
